@@ -18,7 +18,7 @@
     the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
     You may contact the author by:
-       e-mail:  phil@wwu.edu
+       e-mail:  phil@cs.wwu.edu
       us-mail:  Philip A. Nelson
                 Computer Science Department
                 Western Washington University
@@ -27,20 +27,10 @@
 *************************************************************************/
 
 
-/* AIX requires this to be the first thing in the file. */
-#ifdef __GNUC__
-#define alloca	__builtin_alloca
-#else	/* not __GNUC__ */
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#else	/* not HAVE_ALLOCA_H */
-#ifdef _AIX
- #pragma alloca
-#endif	/* not _AIX */
-#endif	/* not HAVE_ALLOCA_H */
-#endif 	/* not __GNUC__ */
-
 /* Include all system headers first. */
+#if HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
 #include <stdio.h>
 #if HAVE_SYS_FILE_H
 #include <sys/file.h>
@@ -49,9 +39,6 @@
 #if HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
 #if HAVE_STRING_H
 #include <string.h>
 #else
@@ -64,6 +51,10 @@
 #include <fcntl.h>
 #endif
 
+#ifndef SEEK_SET
+#define SEEK_SET        0
+#endif
+
 #ifndef L_SET
 #define L_SET SEEK_SET
 #endif
@@ -100,7 +91,7 @@
 	{					\
 	  struct flock flock;			\
 	  flock.l_type = F_UNLCK;		\
-	  flock.l_whence = 0;			\
+	  flock.l_whence = SEEK_SET;		\
 	  flock.l_start = flock.l_len = 0L;	\
 	  fcntl (dbf->desc, F_SETLK, &flock);	\
 	}
@@ -108,7 +99,7 @@
 	{					\
 	  struct flock flock;			\
 	  flock.l_type = F_RDLCK;		\
-	  flock.l_whence = 0;			\
+	  flock.l_whence = SEEK_SET;			\
 	  flock.l_start = flock.l_len = 0L;	\
 	  lock_val = fcntl (dbf->desc, F_SETLK, &flock);	\
 	}
@@ -116,7 +107,7 @@
 	{					\
 	  struct flock flock;			\
 	  flock.l_type = F_WRLCK;		\
-	  flock.l_whence = 0;			\
+	  flock.l_whence = SEEK_SET;			\
 	  flock.l_start = flock.l_len = 0L;	\
 	  lock_val = fcntl (dbf->desc, F_SETLK, &flock);	\
 	}
@@ -124,7 +115,9 @@
 
 /* Do we have bcopy?  */
 #if !HAVE_BCOPY
+#if HAVE_MEMORY_H
 #include <memory.h>
+#endif
 #define bcmp(d1, d2, n)	memcmp(d1, d2, n)
 #define bcopy(d1, d2, n) memcpy(d2, d1, n)
 #endif
@@ -150,9 +143,6 @@
 #define TRUNCATE(dbf) close( open (dbf->name, O_RDWR|O_TRUNC, mode));
 #endif
 
-/* Do we have 32bit or 64bit longs? */
-#if LONG_64_BITS || !INT_16_BITS
-typedef int word_t;
-#else
-typedef long word_t;
+#ifndef STDERR_FILENO
+#define STDERR_FILENO 2
 #endif
